Райффайзенбанк – банк для жизни и бизнеса. Ипотека, кредиты, банковские карты и другие услуги
Description: Райффайзенбанк оказывает полный комплекс банковских услуг частным и корпоративным клиентам. Ипотека, кредиты и вклады в Райффайзенбанке. Работаем в России с 1996 года. Услуги банка онлайн резидентам и нерезидентам, в рублях и иностранной валюте.

- Для жизни
- Малому бизнесу
- Корпоративному бизнесу
- Premium
  Премиальное обслуживание
- Private
  Private Banking
- О банке

- +7 495 777 17 17
  для звонков из Москвы
- 8 800 700-17-17
  для звонков из других регионов

+7 495 721-91-00
Кэшбэк карта

1,5% на всё

Кэшбэк карта Mastercard
Кэшбэк на всё
без условий
и ограничений
0 ₽

обслуживание

1,5%

кэшбэк рублями

0 ₽

доставка

Оформить онлайн Подробнее
Возьмите кредит наличными

Возьмите кредит наличными
8,99%

ставка на весь срок

до 2 млн ₽

сумма кредита

Оформить Подробнее
Программа защиты

от коронавируса для вашей семьи

Программа защиты от коронавируса для вашей семьи
2 млн ₽

максимальная сумма страхового покрытия

1 690 ₽

минимальная стоимость программы

Онлайн

быстрое оформление без посещения отделения банка

Подробнее
110 дней без %

Кредитная карта

Кредитная карта
Кредитная карта
110 дней без %
0 ₽

за снятие наличных

0 ₽

обслуживание карты

0 ₽

доставка карты

Оформить карту Подробнее
от 7,99%

Своя квартира — просто

Ипотека
Своя квартира — просто
от 7,99%

ставка по ипотеке

до 26 млн ₽

cумма кредита

Оформить Подробнее

Накопительные счета

Удобные накопительные счета
Просто откройте в Райффайзен-Онлайн и получайте доход
Открыть счет

Счет для бизнеса онлайн

Расчетно-кассовое обслуживание
Счет для бизнеса онлайн
0 ₽

открытие счета

5 мин.

и реквизиты у вас

1 мин.

заявка на сайте

Открыть счет Подробнее
Новый закон
для самозанятых

Новый закон
для самозанятых
Сделайте свой доход официальным
и встаньте на налоговый учёт
Подробнее

## Станьте клиентом банка

- 1.5% кэшбэк рублями на все покупки
- Бесплатное обслуживание
- До 4,5% на остаток на счете

# Лучшее от банка

## Получить кредит

### от 8,99%

ставка на весь срок

### 1

документ для оформления
Подробнее

## Кредитная карта «110 дней»

### 0 ₽

за снятие наличных

### 0 ₽

обслуживание карты
Подробнее

## Кэшбэк карта

1,5% кэшбэк на всё без условий и ограничений. Бесплатное обслуживание.
Подробнее

## Накопительные счета

### до 4,5%

годовых

### %

начисление ежемесячно
Подробнее

## Малый бизнес

Широкая линейка продуктов для Малого бизнеса!
Расчетно-кассовое обслуживание, Эквайринг, Онлайн касса 54-ФЗ и многое другое
Подробнее

## Премиальное обслуживание

###

персональный менеджер

###

Priority Pass
Подробнее
Горячие скидки и кэшбэк
по картам банка

## Специальные предложения

0 ₽
за снятие наличных по кредитной карте 110 дней без %
1,5 %
кэшбэк на всё без условий и ограничений
Оплата
ЖКУ без лишних движений с Райффайзен-Онлайн
4 мили
За каждые 100 рублей по карте Buy&Fly
Скидки
до 45%
Все предложения
Райффайзен-Онлайн
Простой способ зайти
в банк

## Курсы валют

Валюта
USD
EUR
Покупка
69.30
77.89
Продажа
73.59
82.76
Действуют с 22:00 МСК 03.07.2020
Валюта
USD
EUR
Покупка
69.30
77.90
Продажа
73.60
82.75
Действуют с 18:00 МСК 03.07.2020
Валюта
USD
EUR
Покупка
68.95
77.50
Продажа
73.95
83.15
Действуют с 18:00 МСК 03.07.2020
Валюта
USD
EUR
70.50
79.22
Установлены с 04.07.2020
Курсы Райффайзен-Онлайн

## Офисы и банкоматы

Перейти в раздел

Уважаемые клиенты, предлагаем вам ознакомиться с графиком работы отделений в июне

Новости
02 июля
Не от, а до: Райффайзенбанк снижает ставку рефинансирования кредитов
29 июня
Режим работы отделений 1 июля
22 июня
Изменение тарифов по текущим счетам

Эта страница полезна?

Благодарим за оставленный Вами отзыв! Мы стараемся становиться лучше!

ОтправитьОтменить
Поделиться
Копировать ссылку
Позвонить
Чат с Банком
Написать в WhatsApp
Написать в Viber
Написать в Telegram
Написать e-mail
Выбор региона
Ваш город Москва?
Да
Нет
Онлайн - заявки

- Для жизни
- Для бизнеса

Взять кредит

Наличными на любые нужды

На жилье (ипотеку)

Вложить средства

На вклад

На накопительный счет

В паевые фонды

Банковские карты

Оформить кредитную карту

Оформить дебетовую карту

Начислять зарплату

Стать индивидуальным зарплатным клиентом

Решить проблему с выплатой кредита

Отложить дату очередного платежа

Реструктурировать кредит

Оставить сообщение для банка

Стать VIP-клиентом

Оформить заявку на Пакет услуг Premium Direct

Оформить заявку на Пакет услуг Premium Banking

Малому бизнесу
выручка до 538 млн рублей

Подать заявку на открытие счета

Онлайн заявка на кредит для ИП

Онлайн заявка на кредит для ЮЛ

Среднему и Корпоративному бизнесу
выручка от 538 млн

Заполнить анкету на открытие счета

Оформить банковское обслуживание

Получить кредит

Оформить услугу эквайринга

Дистанционное обслуживание

Получить обратную связь по дистанционному обслуживанию в системе Elbrus

Получить демо-доступ к системе конверсионных операций R-Dealer

+7 495 721-91-00

Контактная информация

Отделения и банкоматы

Обратная связь

Качество обслуживания